"""This file is slightly awkward. It contains the template for using a test
runner in a setup.py file, and a class for using it with setuptools directly.

The test runner can be one of pytest, nose, or unittest.
"""


import os
import unittest
from setuptools.command.test import test as TestCommand


class TestRunner(TestCommand):  # pragma: no cover
    """TestCommand subclass to use pytest or nose with setup.py test."""

    @staticmethod
    def pypackage(config):
        """Set with self when this runner is selected for direct testing."""

        TestRunner._pypackage = config

    def finalize_options(self):
        """Find our package name and test options to fill out test_args."""

        TestCommand.finalize_options(self)
        self.test_args = TestRunner._pypackage.runner_args
        self.test_suite = True

    def run_tests(self):
        """Run tests inline, could be any of pytest, nose or unittest."""

        if TestRunner._pypackage.test_runner == "nose":
            errno = TestRunner._pypackage._runner.main(argv=self.test_args)
        elif TestRunner._pypackage.test_runner == "unittest":
            test_suite = unittest.defaultTestLoader.discover(os.path.abspath(
                getattr(TestRunner._pypackage, "tests_dir", ".")
            ))
            errno = unittest.TextTestRunner().run(test_suite)
        else:
            errno = TestRunner._pypackage._runner.main(self.test_args)

        raise SystemExit(errno)


# for the setup.py; used in config outputting
_TEMPLATE = '''\
from setuptools.command.test import test as TestCommand


class PyPackageTest(TestCommand):
    """TestCommand subclass to enable setup.py test."""

    def finalize_options(self):
        """Find our package name and test options to fill out test_args."""

        TestCommand.finalize_options(self)
        self.test_args = {self.runner_args}
        self.test_suite = True

    def run_tests(self):
        """{self.test_runner} discovery and test execution."""

        import {self.test_runner}
'''


PYTEST_TEMPLATE = _TEMPLATE + \
    "{}raise SystemExit(pytest.main(self.test_args))\n".format(" " * 8)

NOSE_TEMPLATE = _TEMPLATE + \
    "{}raise SystemExit(nose.main(argv=self.test_args))\n".format(" " * 8)


# UNITTEST_TEMPLATE requires the extra tests_dir kwarg to be used with format
UNITTEST_TEMPLATE = _TEMPLATE + """\
        import os

        test_suite = unittest.defaultTestLoader.discover(
            os.path.abspath({tests_dir!r:})
        )
        raise SystemExit(unittest.TextTestRunner().run(test_suite))
"""



"""Functions related to cleaning generated/created files from building."""


import os
import io

from .constants import INPUT


def generated_setup(file_path):
    """Determine if the seutp.py is one we've generated.

    Args:
        file_path: full file path to a setup.py

    Returns:
        True if we've made the setup.py
    """

    trigger = """This file was autogenerated by pypackage. To make changes, you
should edit the pypackage.meta rather than this setup.py."""
    with io.open(file_path, "r", encoding="utf-8") as opensetup:
        return trigger in opensetup.read()


def _generated_files():
    """Finds all generated files in the current working directory.

    Returns:
        list of full file paths
    """

    generated = []
    roots = []
    for root, directories, files in os.walk(os.curdir):
        if root.startswith(("./.tox", "./.eggs", "./venv", "./.venv")):
            continue

        if root.startswith(("./build", "./dist")) \
           or "__pycache__" in root \
           or root.endswith(".egg-info"):
            roots.append(root)

        for file_ in files:
            file_path = os.path.join(root, file_)
            if root.startswith(("./build", "./dist")) \
               or "__pycache__" in root \
               or root.endswith(".egg-info") \
               or file_.endswith(".pyc") \
               or (file_ == "setup.py" and generated_setup(file_path)):
                generated.append(file_path)

    return generated, sorted(roots, reverse=True)


def clean_all(prompt=True):
    """Cleans all generated files.

    Args:
        prompt: boolean to prompt the user to confirm before deleting
    """

    to_delete, roots = _generated_files()
    if prompt:
        print("py-clean will remove the following:\n{}".format(
            "\n".join(to_delete)
        ))
        while True:
            try:
                from_user = INPUT("Are you sure? [y/N] ")
            except KeyboardInterrupt:
                raise SystemExit("Cancelled")
            if from_user.lower().startswith("y"):
                break
            elif from_user.lower().startswith("n"):
                raise SystemExit

    for filepath in to_delete:
        try:
            os.unlink(filepath)
        except Exception as error:
            print("could not delete {}: {!r}".format(filepath, error))

    for root in roots:
        try:
            os.rmdir(root)
        except Exception as error:
            print("could not delete {}: {!r}".format(root, error))



"""Parses flags passed on the command line.

If you're looking for the entry points, they're in commands.py, this only
deals with user options.
"""


import sys
from functools import wraps

from .constants import VERSION


def flags(*args):
    """Returns a boolean of if any of the flags are selected.

    -single character args can be compressed, ie; -e -g == -eg
    """

    cmd_line_flags = []
    for flag in sys.argv:
        if flag.startswith("-") and "--" not in flag and len(flag) > 2:
            cmd_line_flags.extend(["-{}".format(f) for f in flag[1:]])
        else:
            cmd_line_flags.append(flag)
    return any([arg in cmd_line_flags for arg in args])


def get_options():
    """Search through argv real quick and lazy like for some flags.

    Returns:
        configuration object with boolean attributes:
        re_classify, re_config, interactive, setup, metadata, extended,
        re_probe, no_guess, help
    """

    class Options(object):
        def __init__(self):
            self.re_classify = flags("-R", "--reclassify")
            self.re_config = flags("-r", "--reset", "--rebuild")
            self.interactive = flags("-i", "--interactive")
            self.setup = flags("-s", "--setup")
            self.metadata = flags("-m", "--metadata")
            self.extended = flags("-e", "--extended", "--all", "-a")
            self.re_probe = flags("-p", "--reprobe")
            self.no_guess = flags("-N", "--no-guess")
            self.help = flags("-h", "--help")
            self.version = flags("-v", "--version")

    return Options()


def help_and_version(func):
    """Checks for help and/or version flags.

    If the user uses -h/--help it will SystemExit with the function docstring
    If the user uses -v/--version it will SystemExit with pypackage's version
    """

    @wraps(func)
    def _quick_help():
        """Inner wrap function, check for flags or pass on to func."""

        if flags("-h", "--help"):
            raise SystemExit("\n".join([l.replace("    ", "", 1).rstrip() for
                                        l in func.__doc__.splitlines()]))
        elif flags("-v", "--version"):
            raise SystemExit(VERSION)
        else:
            return func()

    return _quick_help



"""Functions and helpers for configuring a config.Config object."""


from __future__ import print_function

import ast
import sys
from pprint import pformat

from .constants import INPUT


def ask_for_value(key):
    """Asks the user for the value of `key`, a key in the config.

    Args:
        key, string config key to query for

    Returns:
        string value from user input, or None on cancel
    """

    user_return = ""
    try:
        user_return = INPUT("Please enter the value for {}: ".format(key))
    except KeyboardInterrupt:
        print("")
        raise SystemExit("Cancelled on user request")
    return user_return or None


def handle_classifiers(config):  # pragma: no cover
    """If -c/--classifiers is used on the command line, enters a curses screen.

    Note: doesn't work on non-POSIX compliant operating systems

    Args:
        config: config object, may have classifiers set on it
    """

    try:
        from .classified import choose_classifiers
    except Exception as error:
        print(error, file=sys.stderr)
        print("Could not load classifiers selector", file=sys.stderr)
    else:
        return choose_classifiers(config)


def set_value_in_config(key, config, keys):
    """Sets a value on config by asking the user for it.

    Args::

        key: string key to ask for
        config: pypackage.config.Config object to add the attribute to
        keys: the key list with type declarations for this key

    Returns:
        None, might add an attribute to config though
    """

    if key == "classifiers":
        user_val = handle_classifiers(config)
    else:
        user_val = ask_for_value(key)

    try:
        user_val = coerce_to_expected(user_val, key, keys[key])
    except Exception as error:
        print(error, file=sys.stderr)
        return set_value_in_config(key, config, keys)

    if user_val:
        setattr(config, key, user_val)

        try:
            config._verify()
        except Exception as error:
            print(error, file=sys.stderr)
            print("{} as {} failed to verify. should be {}".format(
                key, getattr(config, key), keys[key].__name__
            ), file=sys.stderr)
            delattr(config, key)  # unset the failed to verify value
            return set_value_in_config(key, config, keys)
        else:
            print("{} set to: {}".format(key, pformat(getattr(config, key))))


def coerce_to_expected(value, key, type_):
    """Applies some simple logic to coerce value into the expected type.

    Args::

        value: the string returned from the user input
        key: the key name in config we're parsing
        type_: the type declaration for this key value
    """

    if not value:
        return value
    elif ("require" in key and "extras" not in key) or type_ is list:
        return coerce_to_list(value)
    elif isinstance(type_, dict):
        return ast.literal_eval(value)  # oh god, the humanity
    elif type_ is bool:
        try:
            return bool(ast.literal_eval(value))
        except ValueError:
            return bool(value)  # malformed strings get you here, will be True
    elif not isinstance(value, type_):
        return type_(value)
    else:
        return value


def coerce_to_list(value):
    """Splits a value into a list, or wraps value in a list.

    Returns:
        value, as a sorted list
    """

    if isinstance(value, list):
        return sorted(value)
    for split_char in (",", ";", ":", "|", " "):
        if split_char in value:
            return sorted([val.strip() for val in value.split(split_char)])
    return [value]


def standard_attributes(config, options):
    """Builds the list of attributes to query for in the standard category.

    Args:
        config: config object to use
    """

    all_in_this_cat = list(config._KEYS.keys())[:config._STD_TO_EXTD_INDEX]

    if options.re_config:
        return all_in_this_cat

    unconfigured = []
    for key in all_in_this_cat:
        if (key == "classifiers" and options.re_classify) or \
                not hasattr(config, key):
            unconfigured.append(key)

    return unconfigured


def feature_attributes(config, options):
    """Builds a list of unconfigured feature attributes in config."""

    all_in_this_cat = list(config._PYPACKAGE_KEYS.keys())

    if options.re_config:
        return all_in_this_cat

    unconfigured = []
    for key in all_in_this_cat:
        if (key == "runner_args" and not config._configured_runner_args) or \
                not hasattr(config, key):
            unconfigured.append(key)

    return unconfigured


def extended_attributes(config, options):
    """Builds a list of unconfigured extended attributes in config."""

    all_in_this_cat = list(config._KEYS.keys())[config._STD_TO_EXTD_INDEX:]

    if options.re_config:
        return all_in_this_cat

    unconfigured = []
    for key in all_in_this_cat:
        if not hasattr(config, key):
            unconfigured.append(key)

    return unconfigured


def run_interactive_setup(config, options):
    """Interactively fills in attributes of config.

    Args:
        config: pypackage.config.Config object

    Returns:
        config object, probably with more attributes
    """

    if options.re_config:
        print("Reconfiguring{}...".format(
            " {}".format(config.name) if hasattr(config, "name") else ""
        ))
    else:
        print("Starting interactive build{}...".format(
            " for {}".format(config.name) if hasattr(config, "name") else ""
        ))

    def centered(text, size=40, char="~"):
        return text.center(size, char)

    print(centered(" Standard Attributes "))
    for key in standard_attributes(config, options):
        set_value_in_config(key, config, config._KEYS)

    print(centered(" Pypackage Features "))
    for key in feature_attributes(config, options):
        set_value_in_config(key, config, config._PYPACKAGE_KEYS)

    if options.extended:
        print(centered(" Extended Attributes "))
        for key in extended_attributes(config, options):
            set_value_in_config(key, config, config._KEYS)

    return config



"""Pypackage's setup.py"""


import io
from setuptools import setup
from setuptools import find_packages
from setuptools.command.test import test as TestCommand


class PyTest(TestCommand):
    """TestCommand subclass to use pytest with setup.py test."""

    def finalize_options(self):
        """Find our package name and test options to fill out test_args."""

        TestCommand.finalize_options(self)
        self.test_args = ["-v", "-rx", "--cov-report", "term-missing", "--cov",
                          "pypackage", "test"]
        self.test_suite = True

    def run_tests(self):
        """pytest discovery and test execution."""

        import pytest
        raise SystemExit(pytest.main(self.test_args))


def long_description():
    with io.open("README.rst", "r", encoding="utf-8") as openreadme:
        return openreadme.read()


setup(
    name="pypackage",
    version="0.2.6",
    author="Adam Talsma",
    author_email="se-adam.talsma@ccpgames.com",
    url="http://ccpgames.github.io/pypackage",
    download_url="https://github.com/ccpgames/pypackage",
    description="Pypackage looks to package python without writing a setup.py",
    long_description=long_description(),
    packages=find_packages(exclude=["test"]),
    package_data={"pypackage": ["pypackage/classifiers"]},
    include_package_data=True,
    install_requires=[
        "wheel      >= 0.24.0",
        "setuptools >= 15.0",
        "pytest     >= 2.7.0",
        "nose       >= 1.3.0",
        "PyYAML     >= 3.0",
    ],
    cmdclass={"test": PyTest},
    tests_require=["mock", "pytest", "pytest-cov", "requests"],
    entry_points={"console_scripts": [
        "py-build   = pypackage.commands:build",
        "py-develop = pypackage.commands:develop",
        "py-info    = pypackage.commands:info",
        "py-install = pypackage.commands:install",
        "py-setup   = pypackage.commands:setup",
        "py-test    = pypackage.commands:run_tests",
        "py-clean   = pypackage.commands:clean",
    ]},
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Environment :: Console :: Curses',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Software Development',
        'Topic :: Software Development :: Code Generators',
        'Topic :: System :: Archiving :: Packaging',
        'Topic :: System :: Installation/Setup',
        'Topic :: System :: Software Distribution',
        'Topic :: Utilities'
    ],
)



"""Tests to cover the logic in the command line entry points."""


import sys
import mock
import pytest

import pypackage
from pypackage import commands


def test_run_tests():
    """Ensure we call tests correctly..."""

    with mock.patch.object(commands, "pypackage_setup") as patched_setup:
        commands.run_tests()

    patched_setup.assert_called_once_with(
        ["test"],
        additional=commands.run_tests.__doc__,
    )


def test_run_develop():
    """Ensure we call setup.py develop correctly..."""

    with mock.patch.object(commands, "pypackage_setup") as patched_setup:
        commands.develop()

    mock_call = patched_setup.mock_calls[0]
    assert mock_call[1][0] == ["develop", "test"]
    assert mock_call[1][-1] == commands.develop.__doc__


@pytest.mark.parametrize("flag", ("s", "m"), ids=("setup", "metadata"))
def test_no_build(reset_sys_argv, flag):
    """Ensure build is not called if setup or metadata is requested."""

    sys.argv = ["py-build", "-{}".format(flag)]
    opts = mock.Mock()  # mock object attributes respond as True-ish
    with mock.patch.object(commands, "pypackage_setup") as patched_setup:
        with mock.patch.object(commands, "get_options", return_value=opts):
            commands.build()

    patched_setup.assert_called_once_with(
        None,
        additional=commands.build.__doc__,
        options=opts,
    )


def test_setup_entry(reset_sys_argv):
    """Setup's entry is a bit different."""

    sys.argv = ["py-setup"]
    with mock.patch.object(commands, "get_config") as patched_config:
        commands.setup()
    patched_config.assert_called_once_with()


@pytest.mark.parametrize("flag", ("-h", "--help"))
def test_setup_entry__help(reset_sys_argv, flag):
    """Ensure we get the docstring as exit help if the flag is set."""

    sys.argv = ["py-setup", flag]
    with pytest.raises(SystemExit) as patched_exit:
        commands.setup()

    for line in commands.setup.__doc__.splitlines():
        line = line.strip()
        if line:
            assert line in patched_exit.value.args[0]


@pytest.mark.parametrize("flag", ("-v", "--version"))
def test_setup_entry__version(reset_sys_argv, flag):
    """Ensure the VERSION static is raised with SystemExit when requested."""

    sys.argv = ["py-test", flag]
    with pytest.raises(SystemExit) as patched_exit:
        commands.setup()

    assert patched_exit.value.args[0] == pypackage.VERSION


def test_setup_entry__location(reset_sys_argv):
    """Any additonal arguments should be treated as a filepath."""

    sys.argv = ["py-test", "somewhere/on/your/fs"]
    with mock.patch.object(commands, "get_config") as patched_config:
        commands.setup()

    patched_config.assert_called_once_with("somewhere/on/your/fs")


def test_setup_entry__multilocations(reset_sys_argv):
    """All additonal arguments should be treated as a filepath."""

    sys.argv = ["py-test", "place1", "place2"]
    with mock.patch.object(commands, "get_config") as patched_config:
        commands.setup()

    patched_config.assert_any_call("place1")
    patched_config.assert_any_call("place2")

    assert patched_config.call_count == 2


def test_info(reset_sys_argv, capfd):
    """Ensure we're looking up and dumping package metadata to stdout."""

    sys.argv = ["py-info", "pytest"]
    commands.info()
    stdout, stderr = capfd.readouterr()

    assert not stderr
    assert "Name: pytest" in stdout
    assert "License: MIT license" in stdout


def test_info__pkg_not_found(reset_sys_argv, capfd):
    """Ensure the error message when a package is not found."""

    sys.argv = ["py-info", "some-random-non-existant-package"]
    commands.info()
    out, err = capfd.readouterr()

    assert not out
    assert "The package some-random-non-existant-package was not found." in err


def test_info__using_pkg_info(reset_sys_argv, capfd):
    """Verify the metadata when using older-style lookups."""

    def metadata_generator():
        """Mock metadata generator."""
        for line in [
            "Metadata-Version: 1.0",
            "Version: 1.0.0",
            "Source-label: somewords",
            "Source-url: http://yourcompany.com",
        ]:
            yield line
        raise StopIteration

    mock_pkg = mock.Mock()
    mock_pkg.PKG_INFO = "PKG-INFO"
    mock_pkg._get_metadata = mock.Mock(return_value=metadata_generator())

    mockenv = mock.Mock()
    mockenv.__getitem__ = mock.Mock(return_value=[mock_pkg])

    environment_patch = mock.patch.object(
        commands.pkg_resources,
        "Environment",
        return_value=mockenv,
    )

    sys.argv = ["py-info", "foo-bar"]
    with environment_patch:
        commands.info()

    out, err = capfd.readouterr()
    assert not err
    for line in metadata_generator():
        assert line in out


if __name__ == "__main__":
    pytest.main(["-rx", "-v", "--pdb", __file__])



# coding: utf-8
"""Tests for pypackages' guessing features."""


from __future__ import unicode_literals

import io
import os
import sys
import mock
import time
import codecs
import pytest
import random
from collections import OrderedDict

from pypackage import guessing
from pypackage.config import Config
from pypackage.cmdline import get_options


def random_text(length):
    """Returns a random lower-case string of len length."""

    return "".join([
        chr(random.sample(range(97, 123), 1)[0]) for _ in range(length)
    ])


def test_ignored_data_files(with_data):
    """Ensure that files in ignored directories are ignored."""

    root, pkg_root = with_data
    os.mkdir(os.path.join(pkg_root, "build"))
    with open(os.path.join(pkg_root, "build", "data"), "w") as opendata:
        opendata.write("some data")

    data_files = guessing.potential_data_files([])
    expected = [os.path.join(os.path.basename(pkg_root), "data", "data_1")]
    assert data_files == expected


def test_perform_guesswork(capfd, reset_sys_argv, move_home_pypackage):
    """Ensure the user can deselect guesses when using interactive."""

    conf = Config()
    conf.name = "previously existing"
    sys.argv = ["py-build", "-i"]
    guesses = OrderedDict([
        ("name", "some name"),
        ("py_modules", "some_thing"),
        ("scripts", ["bin/something"]),
        ("package_data", ["thing/data/file_1"]),
    ])

    with mock.patch.object(guessing, "_guess_at_things", return_value=guesses):
        with mock.patch.object(guessing, "INPUT",
                               side_effect=iter(["1", "-3", "2", ""])):
            guessing.perform_guesswork(conf, get_options())

    assert conf.name == "previously existing"
    assert not hasattr(conf, "py_modules")
    assert conf.package_data == {"previously existing": ["thing/data/file_1"]}
    assert conf.scripts == ["bin/something"]

    out, err = capfd.readouterr()
    assert "name will not be guessed" in out
    assert "py_modules will not be guessed" in out

    assert not err


def test_perform_guesswork__ignore(capfd, reset_sys_argv, move_home_pypackage):
    """If the user responds with 'all', ignore all guesses."""

    conf = Config()
    conf.name = "previously existing"
    sys.argv = ["py-build", "-i"]
    guesses = OrderedDict([
        ("name", "some name"),
        ("py_modules", "some_thing"),
        ("scripts", ["bin/something"]),
        ("package_data", {"some name": ["thing/data/file_1"]}),
    ])

    with mock.patch.object(guessing, "_guess_at_things", return_value=guesses):
        with mock.patch.object(guessing, "INPUT", return_value="all"):
            guessing.perform_guesswork(conf, get_options())

    assert conf.name == "previously existing"
    assert not hasattr(conf, "py_modules")
    assert not hasattr(conf, "package_data")
    assert not hasattr(conf, "scripts")

    out, err = capfd.readouterr()
    assert "ignoring all guesses" in out
    assert not err


@pytest.mark.parametrize(
    "side_effect",
    (KeyboardInterrupt, EOFError),
    ids=("^C", "^D"),
)
def test_perform_guesswork__interrupts(reset_sys_argv, side_effect):
    """Ensure the user can cleanly exit the interactive session."""

    sys.argv = ["py-build", "-siR"]
    guesses = {"fake": True}
    with mock.patch.object(guessing, "_guess_at_things", return_value=guesses):
        with mock.patch.object(guessing, "INPUT", side_effect=side_effect):
            with pytest.raises(SystemExit) as error:
                guessing.perform_guesswork(Config(), get_options())

    assert error.value.args[0] == "\nInterrupted"


def test_latest_git_tag(simple_package):
    """If the project is under git control and has tags, return the newest."""

    os.mkdir(".git")
    os.mkdir(os.path.join(".git", "refs"))
    os.mkdir(os.path.join(".git", "refs", "tags"))

    for i in range(2):
        if i:
            time.sleep(1.1)

        name = random_text(6)
        contents = random_text(40)
        with open(os.path.join(".git", "refs", "tags", name), "w") as opentag:
            opentag.write(contents)

    assert guessing.find_in_files()["version"] == name


@pytest.fixture
def find_in_files_setup(simple_package):
    """Writes user data to simple_package's __init__.py."""

    pkg_name = os.path.basename(simple_package)
    pkg_root = os.path.join(simple_package, pkg_name)
    init_file = os.path.join(pkg_root, "__init__.py")
    with io.open(init_file, "w", encoding="utf-8") as openinit:
        openinit.writelines([
            "__author__='mike tyson'\n",
            "__email__  =  'irðn@mike.com'\n",
            '_version_=    "1.0.0-final"\n',
            "maintainer = 'don king'\n",
            "maintainer_email = 'don@king.com'\n",
        ])

    return simple_package, pkg_root


def find_in_files_asserts(results):
    """Assert the result set contains the setup information."""

    assert results["author"] == "mike tyson"
    assert results["author_email"] == "irðn@mike.com"
    assert results["version"] == "1.0.0-final"
    assert results["maintainer"] == "don king"
    assert results["maintainer_email"] == "don@king.com"


def test_find_in_files(find_in_files_setup):
    """Write some attribute data to package files and find them."""

    find_in_files_asserts(guessing.find_in_files())


def test_find_in_files__ignored_dir(find_in_files_setup):
    """Ensure data is not considered from ignored directories."""

    ignored_dir = os.path.join(find_in_files_setup[0], "other-pkg.egg")
    os.mkdir(ignored_dir)
    with open(os.path.join(ignored_dir, "__init__.py"), "w") as openinit:
        openinit.write("\n".join([
            "__author__ = 'mohammad ali'",
            "__email__ = 'mo@ali.com'",
            '__version__ = "2.0.0-beta"',
        ]))

    find_in_files_asserts(guessing.find_in_files())


def test_find_in_files__binary_skip(find_in_files_setup):
    """Ensure files that we cannot decode are skipped over."""

    version_file = os.path.join(find_in_files_setup[1], "__version__.py")
    with open(version_file, "wb") as openversionfile:
        openversionfile.write(codecs.encode("__author__ = 'bob'\n", "utf-8"))
        openversionfile.write(codecs.encode("__version__ = '", "utf-8"))
        openversionfile.write(os.urandom(1024))
        openversionfile.write(codecs.encode("'\n", "utf-8"))

    find_in_files_asserts(guessing.find_in_files())


def test_find_in_files__file_too_large(find_in_files_setup):
    """Ensure files that are too large are ignored."""

    # if this file isn't ignored for size, it'll have a higher weight than
    # the data in __init__.py. it's also just over the limit for size
    version_file = os.path.join(find_in_files_setup[1], "__version__.py")

    with open(version_file, "w") as openversionfile:
        openversionfile.write("__author__ = 'bob'\n")
        for _ in range(100):
            openversionfile.write("{}\n".format(random_text(1024)))

    find_in_files_asserts(guessing.find_in_files())


if __name__ == "__main__":
    pytest.main(["-rx", "-v", "--pdb", __file__])
